require 'rest_client'
require 'nokogiri'
require 'active_cmis'

module Grapefruit
  class CmisClient
    attr_accessor :ticket, :repository, :root, :sites

    def initialize(url, username, password)
      @url = url
      @username = username
      @password = password
      fetch_ticket
      #Loading Alfresco repository using active_cmis client
      self.repository = ActiveCMIS.load_config('alfresco_config', File.expand_path(ENV["CMIS_YML"]))
      self.root = repository.root_folder
      self.sites = fetch_sites
    end

    def fetch_ticket
      client = RestClient.get ticket_url
      doc = Nokogiri::XML.parse(client.to_str)
      self.ticket ||= doc.xpath("/ticket").text
    end

    def fetch_sites
      sites = root.items.select { |i| i.name == "Sites" }[0]
    end

    def ticket_url
      "#{@url}/alfresco/service/api/login?u=#{@username}&pw=#{@password}"
    end

    def root_node_url
      "#{ENV['CMIS_HOST']}/alfresco/s/cmis/s/workspace:SpacesStore/i/51ccddc0-d1e6-43fe-b75e-87675659977e/tree"
    end

    def create_folder(folder)
      xml = folder.to_xml
      response = RestClient.post("#{ENV['CMIS_HOST']}/alfresco/s/cmis/p/children?alf_ticket=#{ticket}", xml.strip, :content_type => :atom)
      doc = Nokogiri::XML.parse(response)
      ns = doc.collect_namespaces
      folder.cmis_object_id = doc.xpath("//cmis:propertyId[@propertyDefinitionId='cmis:objectId']", ns).text().strip
      # Handle errors
      folder
    end

  end
end


